pub struct StatusResult {
pub status: String,
pub error: Option<String>,
pub result: JobInfo,
}Expand description
Conversion job status request result
Fields
status: StringStatus holds conversion job status, can be one of the following: pending — a source file is being prepared for conversion. processing — conversion is in progress. finished — the conversion is finished. failed — we failed to convert the source, see error for details. canceled — the conversion was canceled.
error: Option<String>Conversion error if we were unable to handle your file
result: JobInfoResult repeats the contents of your processing output