pub struct ListParams {
pub limit: Option<i32>,
pub ordering: Option<Ordering>,
pub from: Option<String>,
}Expand description
Holds all possible params for for the list method
Fields
limit: Option<i32>Specifies preferred amount of groups in a list for a single response. Defaults to 100, while the maximum is 1000
ordering: Option<Ordering>Specifies the way groups are sorted in a returned list. By default is set to datetime_created.
from: Option<String>A starting point for filtering group lists. MUST be a datetime value with T used as a separator. Example: “2015-01-02T10:00:00”