pub struct JobParams {
pub paths: Vec<String>,
pub store: Option<ToStore>,
}Expand description
Conversion job params
Fields
paths: Vec<String>paths is an array of IDs (UUIDs) of your source documents to convert together with the specified target format. Here is how it should be specified: :uuid/document/-/format/:target-format/
You can also provide a complete CDN URL. It can then be used as an alias to your converted file ID (UUID): https://ucarecdn.com/:uuid/document/-/format/:target-format/
:uuid identifies the source file you want to convert, it should be followed by /document/, otherwise, your request will return an error. /-/ is a necessary delimiter that helps our API tell file identifiers from processing operations.
The following operations are available during conversion: /format/:target-format/ defines the target format you want a source file converted to. The supported values for :target-format are: doc, docx, xls, xlsx, odt, ods, rtf, txt, pdf (default), jpg, png. In case the /format/ operation was not found, your input document will be converted to pdf. Note, when converting multi-page documents to image formats (jpg or png), your output will be a zip archive holding a number of images corresponding to the input page count. /page/:number/ converts a single page of a multi-paged document to either jpg or png. The method will not work for any other target formats. :number stands for the one-based number of a page to convert.
store: Option<ToStore>Flag indicating if we should store your outputs.